"use strict";

/**
 * Get multiple actions sets, connected to this store ready to dispatch to the reducers.
 *
 * @param  {Array} actionSetIDs The unique identifiers of the action sets.
 * @return {Object}             The action set identifiers to connected action function sets.
 */
module.exports = connectActionSets;

var INTROSPECTION_TYPE = require("./types").INTROSPECTION_TYPE;

/**
 * Get a set of actions, connected to this store ready to dispatch to the reducers.
 *
 * @param  {String} actionSetID The unique identifier for the action set
 * @return {Object}             The connected action functions
 */
function getConnectedActionSet(_ref) {
  var actionSet = _ref.actionSet;
  var actionSetID = _ref.actionSetID;
  var getAllConnectedActionSets = _ref.getAllConnectedActionSets;
  var dispatch = _ref.dispatch;
  var getConsensusForIntrospection = _ref.getConsensusForIntrospection;

  var connectedActionSet = {};

  Object.keys(actionSet).forEach(function (actionID) {
    if (actionID === INTROSPECTION_TYPE) {
      var introspectionIDs = Object.keys(actionSet[INTROSPECTION_TYPE]);
      connectedActionSet.getConsensus = introspectionIDs.reduce(function (consensusFunctions, introspectionID) {
        consensusFunctions[introspectionID] = getConsensusForIntrospection(introspectionID);
        return consensusFunctions;
      }, {});
      return;
    }

    var sourceActionFunction = actionSet[actionID];

    connectedActionSet[actionID] = function (payload) {
      // Synchronous, immediately dispatched
      if (sourceActionFunction.length <= 1) {
        var result = sourceActionFunction(payload);
        // Allow empty action declarations
        if (typeof result !== "undefined") {
          payload = result;
        }
        dispatch({ actionSetID: actionSetID, actionID: actionID, payload: payload });
      }
      // Asychronous, delegates the dispatching
      else {
        sourceActionFunction(payload, {
          currentActionSet: connectedActionSet,
          allActionSets: getAllConnectedActionSets()
        });
      }
    };
  });

  return connectedActionSet;
}function connectActionSets(_ref) {
  var actionSets = _ref.actionSets;
  var dispatch = _ref.dispatch;
  var getConsensusForActionSet = _ref.getConsensusForActionSet;

  return Object.keys(actionSets).reduce(function (connectedActionSets, actionSetID) {
    connectedActionSets[actionSetID] = getConnectedActionSet({
      actionSet: actionSets[actionSetID],
      actionSetID: actionSetID,
      getAllConnectedActionSets: function getAllConnectedActionSets() {
        return connectedActionSets;
      },
      dispatch: dispatch,
      getConsensusForIntrospection: getConsensusForActionSet(actionSetID)
    });

    return connectedActionSets;
  }, {});
}