"use strict";

/**
 * Attach multiple reducers, with ids as keys and reducer function sets as values.
 *
 * @param  {Object} reducers An object mapping identifiers to reducer function sets
 * @param  {Object} idToProps    (Optional) the unique attributes for each particular reducer
 */

module.exports = function (_ref) {
  var reducers = _ref.reducers;
  var idToProps = _ref.idToProps;

  var resources = {};
  var states = {};

  Object.keys(reducers).forEach(function (id) {
    var resource = {
      reducer: reducers[id],
      props: idToProps[id]
    };

    resources[id] = resource;
    states[id] = resource.reducer.getInitialState(resource.props);
  });

  return { resources: resources, states: states };
};