"use strict";

var _interopRequire = function (obj) { return obj && obj.__esModule ? obj["default"] : obj; };

exports.createRootReducer = createRootReducer;
exports.connectActionSetsToStore = connectActionSetsToStore;

var createResourcesFromReducers = _interopRequire(require("./createResourcesFromReducers"));

var dispatch = _interopRequire(require("./dispatch"));

var getConsensus = _interopRequire(require("./getConsensus"));

var connectActionSets = _interopRequire(require("./connectActionSets"));

var FLAMBEAU_ACTION_TYPE = "flambeau";

function createRootReducer(_ref) {
  var reducers = _ref.reducers;
  var idToProps = _ref.idToProps;

  var _createResourcesFromReducers = createResourcesFromReducers({ reducers: reducers, idToProps: idToProps });

  var resources = _createResourcesFromReducers.resources;
  var states = _createResourcesFromReducers.states;

  var initialState = Object.assign(states, {
    _resources: resources
  });

  return function (_x, action) {
    var state = arguments[0] === undefined ? initialState : arguments[0];

    if (action.type === FLAMBEAU_ACTION_TYPE && action.actionSetID && action.actionID && action.payload) {
      var changedStates = dispatch({ resources: state._resources, states: state })(action);

      return Object.assign({}, state, changedStates);
    }

    return state;
  };
}

function connectActionSetsToStore(_ref) {
  var actionSets = _ref.actionSets;
  var store = _ref.store;

  return connectActionSets({
    actionSets: actionSets,
    dispatch: function (payload) {
      store.dispatch(Object.assign({
        type: FLAMBEAU_ACTION_TYPE
      }, payload));
    },
    getConsensusForActionSet: function (actionSetID) {
      var state = store.getState();
      return getConsensus({
        resources: state._resources,
        states: state
      })(actionSetID);
    }
  });
}
Object.defineProperty(exports, "__esModule", {
  value: true
});